import aquila_borg as borg
import configparser

cons = borg.console()
myprint = lambda x: cons.print_std(x) if type(x) == str else cons.print_std(repr(x))

def get_cosmopar(ini_file):
    """
    Extract cosmological parameters from an ini file
    
    Args:
        :ini_file (str): Path to the ini file
    
    Returns:
        :cpar (borg.cosmo.CosmologicalParameters): Cosmological parameters
    """
    
    config = configparser.ConfigParser()
    config.read(ini_file)
        
    cpar = borg.cosmo.CosmologicalParameters()
    cpar.default()
    cpar.fnl = float(config['cosmology']['fnl'])
    cpar.omega_k = float(config['cosmology']['omega_k'])
    cpar.omega_m = float(config['cosmology']['omega_m'])
    cpar.omega_b = float(config['cosmology']['omega_b'])
    cpar.omega_q = float(config['cosmology']['omega_q'])
    cpar.h = float(config['cosmology']['h100'])
    cpar.sigma8 = float(config['cosmology']['sigma8'])
    cpar.n_s = float(config['cosmology']['n_s'])
    cpar.w = float(config['cosmology']['w'])
    cpar.wprime = float(config['cosmology']['wprime'])
    cpar.A_s = 1.e-9 * symbolic_pofk.linear.sigma8_to_As(
            cpar.sigma8, cpar.omega_m, cpar.omega_b, cpar.h, cpar.n_s)
    
    return cpar
